References
##########

.. _references:

.. [ArFW00] Arnold, D. N., R. S. Falk, and R. Winther, 2000, Multigrid in
   H(div) and H(curl): Numerische Mathematik, 85, 197--217;
   DOI: `10.1007/PL00005386 <https://doi.org/10.1007/PL00005386>`_.
.. [BrHM00] Briggs, W., V. Henson, and S. McCormick, 2000, A Multigrid
   Tutorial, Second Edition: Society for Industrial and Applied Mathematics;
   DOI: `10.1137/1.9780898719505 <https://doi.org/10.1137/1.9780898719505>`_.
.. [ClWe01] Clemens, M., and T. Weiland, 2001, Discrete electromagnetism with
   the finite integration technique: PIER, 32, 65--87; DOI:
   `10.2528/PIER00080103 <https://doi.org/10.2528/PIER00080103>`_.
.. [Fedo64] Fedorenko, R. P., 1964, The speed of convergence of one iterative
   process: USSR Computational Mathematics and Mathematical Physics, 4,
   227--235; DOI `10.1016/0041-5553(64)90253-8
   <https://doi.org/10.1016/0041-5553(64)90253-8>`_.
.. [JoOM06] Jönsthövel, T. B., C. W. Oosterlee, and W. A. Mulder, 2006,
   Improving multigrid for 3-D electro-magnetic diffusion on stretched grids:
   European Conference on Computational Fluid Dynamics; UUID:
   `df65da5c-e43f-47ab-b80d-2f8ee7f35464
   <http://resolver.tudelft.nl/uuid:df65da5c-e43f-47ab-b80d-2f8ee7f35464>`_.
.. [MoSu94] Monk, P., and E. Süli, 1994, A convergence analysis of Yee's scheme
   on nonuniform grids: SIAM Journal on Numerical Analysis, 31, 393--412; DOI
   `10.1137/0731021 <https://doi.org/10.1137/0731021>`_.
.. [Muld06] Mulder, W. A., 2006, A multigrid solver for 3D electromagnetic
   diffusion: Geophysical Prospecting, 54, 633--649; DOI:
   `10.1111/j.1365-2478.2006.00558.x
   <https://doi.org/10.1111/j.1365-2478.2006.00558.x>`_.
.. [Muld07] Mulder, W. A., 2007, A robust solver for CSEM modelling on
   stretched grids: EAGE Technical Program Expanded Abstracts, D036;
   DOI `10.3997/2214-4609.201401567
   <https://doi.org/10.3997/2214-4609.201401567>`_.
.. [Muld08] Mulder, W. A., 2008, Geophysical modelling of 3D electromagnetic
   diffusion with multigrid: Computing and Visualization in Science, 11,
   29--138; DOI: `10.1007/s00791-007-0064-y
   <https://doi.org/10.1007/s00791-007-0064-y>`_.
.. [Muld11] Mulder, W. A., 2011, *in* Numerical Methods, Multigrid: Springer
   Netherlands, 895--900; DOI `10.1007/978-90-481-8702-7_153
   <https://doi.org/10.1007/978-90-481-8702-7_153>`_.
.. [MuWS08] Mulder, W. A., M. Wirianto, and E. C. Slob, 2008, Time-domain
   modeling of electromagnetic diffusion with a frequency-domain code:
   Geophysics, 73, F1--F8; DOI: `10.1190/1.2799093
   <https://doi.org/10.1190/1.2799093>`_.
.. [PlDM07] Plessix, R.-E., M. Darnet, and W. A. Mulder, 2007, An approach for
   3D multisource, multifrequency CSEM modeling: Geophysics, 72, SM177--SM184;
   DOI: `10.1190/1.2744234 <https://doi.org/10.1190/1.2744234>`_.
.. [SlHM10] Slob, E., J. Hunziker, and W. A. Mulder, 2010, Green's tensors for
   the diffusive electric field in a VTI half-space: PIER, 107, 1--20: DOI:
   `10.2528/PIER10052807 <http://doi.org/10.2528/PIER10052807>`_.
.. [Weil77] Weiland, T., 1977, Eine Methode zur Lösung der Maxwellschen
   Gleichungen für sechskomponentige Felder auf diskreter Basis: Archiv für
   Elektronik und Übertragungstechnik, 31, 116--120; pdf:
   `leibniz-publik.de/de/fs1/object/display/bsb00064886_00001.html
   <https://www.leibniz-publik.de/de/fs1/object/display/bsb00064886_00001.html>`_.
.. [WeMS19] Werthmüller, D., W. A. Mulder, and E. C. Slob, 2019, emg3d: A
   multigrid solver for 3D electromagnetic diffusion: Journal of Open Source
   Software, 4(39), 1463;
   DOI: `10.21105/joss.01463 <https://doi.org/10.21105/joss.01463>`_.
.. [WiMS10] Wirianto, M., W. A. Mulder, and E. C. Slob, 2010, A feasibility
   study of land CSEM reservoir monitoring in a complex 3-D model: Geophysical
   Journal International, **181**, 741--755; DOI:
   `10.1111/j.1365-246X.2010.04544.x
   <https://doi.org/10.1111/j.1365-246X.2010.04544.x>`_.
.. [WiMS11] Wirianto, M., W. A. Mulder, and E. C. Slob, 2011, Applying
   essentially non-oscillatory interpolation to controlled-source
   electromagnetic modelling: Geophysical Prospecting, 59, 161--175; DOI:
   `10.1111/j.1365-2478.2010.00899.x
   <https://doi.org/10.1111/j.1365-2478.2010.00899.x>`_.
.. [Yee66] Yee, K., 1966, Numerical solution of initial boundary value problems
   involving maxwell's equations in isotropic media: IEEE Transactions on
   Antennas and Propagation, 14, 302--307; DOI: `10.1109/TAP.1966.1138693
   <https://doi.org/10.1109/TAP.1966.1138693>`_.
